@@ -5,7 +5,7 @@ from fastapi_admin import enums
 
 class User(Model):
     username = fields.CharField(max_length=20, unique=True)
-    password = fields.CharField(max_length=200)
+    password = fields.CharField(max_length=200, description="Will auto hash with raw password")
 
     class Meta:
         abstract = True
@@ -15,7 +15,7 @@ class Permission(Model):
     label = fields.CharField(max_length=50)
     model = fields.CharField(max_length=50)
     action: enums.PermissionAction = fields.IntEnumField(
-        enums.PermissionAction, default=enums.PermissionAction.read, description="Permission Action"
+        enums.PermissionAction, default=enums.PermissionAction.read
     )
 
     def __str__(self):
