@@ -1,4 +1,4 @@
-from typing import Optional, Tuple, Dict, Union, List, Set
+from typing import Dict, List, Optional, Set, Tuple, Union
 
 from pydantic import BaseModel, HttpUrl
 
@@ -11,7 +11,7 @@ class Menu(BaseModel):
     url: Optional[str]
     icon: Optional[str]
     # children menu
-    children: Optional[List['Menu']] = []
+    children: Optional[List["Menu"]] = []
     # include fields
     include: Optional[Tuple[str]]
     # exclude fields
@@ -26,13 +26,12 @@ class Menu(BaseModel):
     sort_fields: Optional[Set[str]] = set()
     # define field type,like select,radiolist,text,date
     fields_type: Dict = {}
-    actions: Dict = {
-        'export': True
-    }
-    bulk_actions: List[Dict] = [{
-        'value': 'delete',
-        'text': 'delete_all',
-    }]
+    # define field attr,like cols which in bootstrap table
+    attrs: Dict[str, Dict] = {}
+    # active table export
+    export: bool = True
+    actions: Optional[Dict]
+    bulk_actions: List[Dict] = [{"value": "delete", "text": "delete_all",}]
 
 
 Menu.update_forward_refs()
@@ -40,7 +39,11 @@ Menu.update_forward_refs()
 
 class Site(BaseModel):
     name: str
-    logo: HttpUrl
+    logo: Optional[HttpUrl]
+    login_logo: Optional[HttpUrl]
+    login_footer: Optional[str]
+    login_description: Optional[str]
+    footer: Optional[str]
     locale: str
     locale_switcher: bool = False
     theme_switcher: bool = False
@@ -50,7 +53,7 @@ class Site(BaseModel):
     # custom css
     css: Optional[List[HttpUrl]]
     # menu define
-    menus: List[Menu]
+    menus: Optional[List[Menu]]
     # custom footer with html
     footer: Optional[str]
 
@@ -76,8 +79,9 @@ class Resource(BaseModel):
     resource_fields: Dict[str, Union[Field, Dict]]
     searchFields: Optional[Dict[str, Field]]
     bulk_actions: Optional[List[Dict]]
+    export: bool
 
     class Config:
         fields = {
-            'resource_fields': 'fields',
+            "resource_fields": "fields",
         }
